@@ -52,7 +52,7 @@ extern Fl_Double_Window *scopeview;
 
 extern Fl_Double_Window *dlgRecordLoader;
 
-extern bool				NBEMSapps_dir;
+extern bool first_use;
 
 extern FTextRX			*ReceiveText;
 extern FTextTX			*TransmitText;
@@ -259,6 +259,8 @@ extern void init_modem_squelch(trx_mode mode, int freq = 0);
 
 extern void start_tx();
 extern void abort_tx();
+extern void set_rx_tx();
+extern void set_rx_only();
 
 extern void LOGGING_colors_font();
 extern void LOGBOOK_colors_font();
@@ -341,4 +343,6 @@ extern void cb_mnuCheckUpdate(Fl_Widget *, void *);
 
 bool ask_dir_creation( const std::string & dir );
 
+extern void set_CSV(int how);
+
 #endif
