@@ -192,12 +192,11 @@ void ParseMode(string src)
 	for (size_t i = 0; i < NUM_MODES; ++i) {
 		if (strlen(mode_info[i].pskmail_name) > 0) {
 			if (src == mode_info[i].pskmail_name) {
-//				while (trx_state != STATE_RX) {
-//					MilliSleep(10);
-//				}
-				if (debug_pskmail)
-					LOG_INFO("Setting modem to %s", mode_info[i].pskmail_name);
 				REQ_SYNC(init_modem_sync, mode_info[i].mode, 0);
+				AbortARQ();
+				WriteARQ('\002');
+				if (debug_pskmail)
+					LOG_INFO("Modem set to %s", mode_info[i].pskmail_name);
 				break;
 			}
 		}
@@ -355,7 +354,6 @@ static	string TLFlogname;
 static bool TLF_arqRx()
 {
 	/// The mutex is automatically unlocked when returning.
-	guard_lock arq_rx_lock(&arq_rx_mutex);
 #if defined(__WOE32__) || defined(__APPLE__)
 	return false;
 #else
@@ -393,6 +391,7 @@ static bool TLF_arqRx()
 		}
 
 		if (arqtext.empty() && !txstring.empty()) {
+			guard_lock arq_rx_lock(&arq_rx_mutex);
 			arqtext = txstring;
 			if (mailserver && progdefaults.PSKmailSweetSpot)
 				active_modem->set_freq(progdefaults.PSKsweetspot);
@@ -627,9 +626,14 @@ void WriteARQsocket(unsigned char* data, size_t len)
 	if (arqclient.empty()) return;
 	static string instr;
 	instr.clear();
+
+	string outs = "";
+	for (unsigned int i = 0; i < len; i++)
+		outs += asc[data[i] & 0x7F];
+	LOG_INFO("%s", outs.c_str());
+
 	vector<ARQCLIENT>::iterator p;
-	p = arqclient.begin();
-	while (p != arqclient.end()) {
+	for (p = arqclient.begin(); p < arqclient.end(); p++) {
 		try {
 			(*p).sock.wait(1);
 			(*p).sock.send(data, len);
@@ -647,11 +651,6 @@ void WriteARQsocket(unsigned char* data, size_t len)
 		}
 	}
 
-	string outs = "";
-	for (unsigned int i = 0; i < len; i++)
-		outs += asc[data[i] & 0x7F];
-	LOG_INFO("%s", outs.c_str());
-
 	if (arqclient.empty()) arq_reset();
 }
 
@@ -725,18 +724,17 @@ bool Socket_arqRx()
 		if (arqclient.empty()) arq_reset();
 	}
 
+	if (!txstring.empty()) parse_arqtext(txstring);
+
+	if (abort_flag) {
+		AbortARQ();
+		abort_flag = false;
+		return true;
+	}
+
 	{
 	/// Mutex is unlocked when leaving block
 		guard_lock arq_rx_lock(&arq_rx_mutex);
-		if (!txstring.empty()) parse_arqtext(txstring);
-
-		if (abort_flag) {
-			AbortARQ();
-			abort_flag = false;
-			return true;
-		}
-
-		{
 
 		if (txstring.empty()) return false;
 
@@ -758,7 +756,7 @@ bool Socket_arqRx()
 
 		arq_text_available = true;
 		active_modem->set_stopflag(false);
-		}
+
 	}
 	return true;
 }
@@ -855,7 +853,7 @@ int arq_get_char()
 	guard_lock arq_rx_lock(&arq_rx_mutex);
 	int c = 0;
 	if (arq_text_available) {
-		if (pText != arqtext.length()) {
+		if (!arqtext.empty() && pText != arqtext.length()) {
 			c = arqtext[pText++] & 0xFF;
 		} else {
 			arqtext.clear();
@@ -878,8 +876,6 @@ void AbortARQ() {
 	arqtext.clear();
 	txstring.clear();
 	pText = 0;
-	arq_text_available = false;
-//	bSend0x06 = true;
 }
 
 //======================================================================
