@@ -386,9 +386,10 @@ void configuration::loadDefaults()
 {
 // RTTY
 	selShift->index(rtty_shift);
-	if (progdefaults.rtty_shift == selShift->lsize() - 1)
+	if (progdefaults.rtty_shift == selShift->lsize() - 1) {
 		selCustomShift->activate();
-	else
+		selCustomShift->value(rtty_custom_shift);
+	} else
 		selCustomShift->deactivate();
 	selBaud->index(rtty_baud);
 	selBits->index(rtty_bits);
@@ -863,7 +864,10 @@ void configuration::testCommPorts()
 #if defined(__linux__)
 		"/dev/ttyS%u",
 		"/dev/ttyUSB%u",
-		"/dev/usb/ttyUSB%u"
+		"/dev/usb/ttyUSB%u",
+		"/dev/ttyACM%u",
+		"/dev/usb/ttyACM%u",
+		"/opt/vttyS%u"
 #elif defined(__FreeBSD__) || defined(__OpenBSD__) || defined(__NetBSD__)
 		"/dev/tty%2.2u"
 #elif defined(__CYGWIN__)
