@@ -1220,7 +1220,10 @@ static void pTX(std::string &s, size_t &i, size_t endbracket)
 		return;
 	}
 	s.erase(i, 4);
-	TransmitON = true;
+	if (rx_only)
+		TransmitON = false;
+	else
+		TransmitON = true;
 }
 
 static void pTXRX(std::string &s, size_t &i, size_t endbracket)
@@ -1230,7 +1233,10 @@ static void pTXRX(std::string &s, size_t &i, size_t endbracket)
 		return;
 	}
 	s.erase(i, 7);
-	ToggleTXRX = true;
+	if (rx_only)
+		ToggleTXRX = false;
+	else
+		ToggleTXRX = true;
 }
 
 static std::string hexstr(std::string &s)
@@ -1820,6 +1826,25 @@ static void pRX_RSID(std::string &s, size_t &i, size_t endbracket)
   s.replace(i, endbracket - i + 1, "");
 }
 
+static void pCSV(std::string &s, size_t &i, size_t endbracket)
+{
+	if (within_exec) {
+		s.replace(i, endbracket - i + 1, "");
+		return;
+	}
+  std::string sVal = s.substr(i+5, endbracket - i - 5);
+  if (sVal.length() > 0) {
+    // sVal = on|off   [ON, OFF]
+    if (sVal.compare(0,2,"on") == 0)
+		set_CSV(1);
+    else if (sVal.compare(0,3,"off") == 0)
+		set_CSV(0);
+	else if (sVal.compare(0,1,"t") == 0)
+		set_CSV(2);
+  }
+  s.replace(i, endbracket - i + 1, "");
+}
+
 #ifdef __WIN32__
 static void pTALK(std::string &s, size_t &i, size_t endbracket)
 {
@@ -2667,6 +2692,7 @@ static const MTAGS mtags[] = {
 #ifdef __WIN32__
 {"<TALK:",		pTALK},
 #endif
+{"<CSV:",		pCSV},
 {"<WX>",		pWX},
 {"<WX:",		pWX2},
 {"<IMAGE:",		pQueIMAGE},
@@ -2853,7 +2879,7 @@ std::string MACROTEXT::expandMacro(std::string &s, bool recurse = false)
 {
 	size_t idx = 0;
 	expand = true;
-	if (!recurse) {
+	if (!recurse || rx_only) {
 		TransmitON = false;
 		ToggleTXRX = false;
 	}
@@ -2943,7 +2969,8 @@ void idleTimer(void *)
 
 static void continueMacro(void *)
 {
-	if ( TransmitON ) {
+	if (rx_only) TransmitON = false;
+	else if ( TransmitON) {
 		active_modem->set_stopflag(false);
 		if (macro_idle_on && idleTime > 0)
 			Fl::add_timeout(idleTime, idleTimer);
@@ -2962,6 +2989,11 @@ static void finishTune(void *)
 
 static void finishWait(void *)
 {
+	if (rx_only) {
+		TransmitON = false;
+		useTune = false;
+		return;
+	}
 	if (useTune && tuneTime > 0) {
 		trx_tune();
 		Fl::add_timeout(tuneTime, finishTune);
@@ -2987,11 +3019,13 @@ void MACROTEXT::timed_execute()
 {
 	queue_reset();
 	TransmitText->clear();
-	text2send = expandMacro(exec_string);
-	TransmitText->add_text(text2send);
-	exec_string.clear();
-	active_modem->set_stopflag(false);
-	start_tx();
+	if (!rx_only) {
+		text2send = expandMacro(exec_string);
+		TransmitText->add_text(text2send);
+		exec_string.clear();
+		active_modem->set_stopflag(false);
+		start_tx();
+	}
 }
 
 void MACROTEXT::execute(int n)
@@ -3007,16 +3041,18 @@ void MACROTEXT::execute(int n)
 		return;
 	}
 
-	if (progStatus.repeatMacro == -1)
-		TransmitText->add_text( text2send );
-	else {
-		size_t p = std::string::npos;
-		text2send = text[n];
-		while ((p = text2send.find('<')) != std::string::npos)
-			text2send[p] = '[';
-		while ((p = text2send.find('>')) != std::string::npos)
-			text2send[p] = ']';
-		TransmitText->add_text( text2send );
+	if (!rx_only) {
+		if (progStatus.repeatMacro == -1)
+			TransmitText->add_text( text2send );
+		else {
+			size_t p = std::string::npos;
+			text2send = text[n];
+			while ((p = text2send.find('<')) != std::string::npos)
+				text2send[p] = '[';
+			while ((p = text2send.find('>')) != std::string::npos)
+				text2send[p] = ']';
+			TransmitText->add_text( text2send );
+		}
 	}
 	text2send.clear();
 
