@@ -35,9 +35,10 @@
 
 #include "timeops.h"
 
-#ifdef __clang__
-#  define MAP_TYPE std::unordered_map
-#  include <unordered_map>
+#if HAVE_STD_HASH
+#	define MAP_TYPE std::unordered_map
+#	define HASH_TYPE std::hash
+#	include <unordered_map>
 #else
 #	if (__GNUC__ > 4) || (__GNUC__ == 4 && __GNUC_MINOR__ >= 1)
 #		define MAP_TYPE std::tr1::unordered_map
